package ai.pai.lensman.briefs;

import android.os.AsyncTask;

import com.android.common.executors.ThreadExecutor;

import org.json.JSONObject;

import java.util.HashMap;

import ai.pai.lensman.base.BaseInteractor;
import ai.pai.lensman.bean.BriefsBean;
import ai.pai.lensman.db.Preferences;
import ai.pai.lensman.utils.HttpPostTask;
import ai.pai.lensman.utils.UrlContainer;

/**
 * Created by chengzhenyu on 2016/8/24.
 */

public class BriefsInteractor implements BaseInteractor {

    private HttpPostTask fetchInfoTask;
    private InteractorListener<BriefsBean> listener;

    public BriefsInteractor(InteractorListener<BriefsBean> listener){
        this.listener = listener;
    }

    @Override
    public void startJob() {
        HashMap<String,String> params = new HashMap<>();
        params.put("user_id", Preferences.getInstance().getLensManId());
        fetchInfoTask = new HttpPostTask(params){

            String message;
            BriefsBean bean;

            @Override
            protected boolean parseResponse(String response) {
                try{
                    JSONObject json = new JSONObject(response);
                    int status = json.getInt("status");
                    if(status == 200){
                        bean = new BriefsBean();
                        return true;
                    }else{
                        message = json.getString("message");
                    }
                }catch (Exception e){
                    e.printStackTrace();
                }
                return false;
            }

            @Override
            protected void onPostFail() {
                super.onPostFail();
                listener.onInteractFail(message);
            }

            @Override
            protected void onPostSuccess() {
                super.onPostSuccess();
                listener.onInteractSuccess(bean);
            }
        };
        fetchInfoTask.executeOnExecutor(ThreadExecutor.getInstance().getExecutor(), UrlContainer.SESSION_IDS_CREATE);
    }

    @Override
    public void cancelJob() {
        if(fetchInfoTask==null){
            return;
        }
        if(fetchInfoTask.getStatus()== AsyncTask.Status.RUNNING){
            fetchInfoTask.cancel(true);
        }
        fetchInfoTask = null;
    }
}
